@@ -38,10 +38,10 @@ skip_glob = '^((?!py$).)*$'    # this makes sort all Python files
 known_third_party = ["cognite"]
 
 [tool.poetry.dependencies]
-python = "^3.7"
+python = ">=3.7,<3.11"
 
 [tool.poetry.dev-dependencies]
-pyinstaller = "^4.0"
+pyinstaller = "^4.7"
 macholib = {{version = "^1.14", platform = "darwin"}}             # Used by pyinstaller pn Mac OS
 pywin32-ctypes = {{version = "^0.2.0", platform = "win32"}}       # Used by pyinstaller on Windows
 pefile = "^2019.4.18"                                           # Used by pyinstaller on Windows
@@ -192,7 +192,7 @@ def initialize_project() -> None:
         extractor_file.write(extractor_template.format(name=name))
 
     os.system("poetry run pip install --upgrade pip")
-    os.system("poetry add cognite-sdk cognite-extractor-utils")
+    os.system("poetry add cognite-sdk-core cognite-extractor-utils")
     os.system("poetry add -D mypy flake8 black isort pre-commit")
     os.system("poetry lock")
     os.system("poetry install")
